@@ -106,7 +106,7 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
         vertexType=rawSchemaJson["vertex"][vertexI]["node_type"]
         csvDfItem["newMadeSysID"]=vertexType+"_"+csvDfItem[rawSchemaJson["vertex"][vertexI]["id_col"]].astype(str)
 
-        coverLabel=rawSchemaJson["vertex"][vertexI].get("cover_label","cover,escape")
+        coverLabel=rawSchemaJson["vertex"][vertexI].get("cover_label","escape,cover")
         vertexDataProcess=coverLabel.split(",")[0]
         vertexAttrProcess=coverLabel.split(",")[1]
 
@@ -129,39 +129,37 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
             csvDfItem=pd.DataFrame([row for row in json.loads(csvDfItem.to_json(orient="records")) 
                                         if existTag(nodeType, nodeIdAttr, row[rawSchemaJson["vertex"][vertexI]["id_col"]],gClient)==False])
         elif vertexAttrProcess=="plus":
+            
+            nodeItemCInfoDf=csvDfItem.copy(deep=True)
+            
             nodeType=rawSchemaJson["vertex"][vertexI]["node_type"]
             nodeIdAttr=rawSchemaJson["vertex"][vertexI]["id_col"]
-            nodeIdList=csvDfItem[rawSchemaJson["vertex"][vertexI]["id_col"]].values.flatten().tolist()
-            csvDfItemList=[]
-            for nodeIdItem in tqdm.tqdm(nodeIdList):
-                if existTag(nodeType, nodeIdAttr, nodeIdItem,gClient)==True:
-                    queryStr="LOOKUP ON {nodeType} WHERE {nodeType}.{nodeIdAttr}=='{nodeIdVal}'| FETCH PROP ON {nodeType} $-.VertexID".format(nodeType=nodeType,
-                                                                                                                                                            nodeIdAttr=nodeIdAttr,
-                                                                                                                                                            nodeIdVal=nodeIdItem)
-                    # print(queryStr)
-                    nodeItemGInfoDf=wrapNebula2Df(gClient.execute_query(queryStr))
-                    nodeItemGInfoDict=json.loads(nodeItemGInfoDf.to_json(orient="records"))[0]
-                    nodeItemCInfoDf=csvDfItem.loc[csvDfItem[rawSchemaJson["vertex"][vertexI]["id_col"]]==nodeIdItem,:]
-                    nodeItemCInfoDict=json.loads(nodeItemCInfoDf.to_json(orient="records"))[0]
-                    for keyItem in nodeItemGInfoDict:
-                        if "." in keyItem and keyItem!=rawSchemaJson["vertex"][vertexI]["id_col"]:
-                            realCKeyItem=keyItem.split(".")[1]
-                            if nodeItemGInfoDict[keyItem]!="null" and \
-                                nodeItemGInfoDict[keyItem] is not None and\
-                                (
-                                    nodeItemCInfoDict[realCKeyItem] == "null" or\
-                                    nodeItemCInfoDict[realCKeyItem] is None or\
-                                    (
-                                        type(nodeItemCInfoDict[realCKeyItem])==str and\
-                                        len(nodeItemCInfoDict[realCKeyItem])==0
-                                    ) or\
-                                    (type(nodeItemCInfoDict[realCKeyItem])==float and np.isnan(nodeItemCInfoDict[realCKeyItem]))
-                                ):
-                                nodeItemCInfoDict[realCKeyItem]=nodeItemGInfoDict[keyItem]
-                    csvDfItemList.append(nodeItemCInfoDict)
-                else:
-                    csvDfItemList.extend(json.loads(csvDfItem.loc[csvDfItem[rawSchemaJson["vertex"][vertexI]["id_col"]]==nodeIdItem,:].to_json(orient="records")))
-            csvDfItem=pd.DataFrame(csvDfItemList)
+            nodeIdList=nodeItemCInfoDf[rawSchemaJson["vertex"][vertexI]["id_col"]].values.flatten().tolist()
+            
+            searchBatch=32
+            nodeItemGInfoDfList=[]
+            for nodeIdI in range(0,len(nodeIdList),searchBatch):
+                queryStrList=[]
+                for nodeIdIItem in range(nodeIdI,nodeIdI+searchBatch):
+                    queryStrItem="LOOKUP ON {nodeType} WHERE {nodeType}.{nodeIdAttr}=='{nodeIdVal}'| FETCH PROP ON {nodeType} $-.VertexID".format(nodeType=nodeType,
+                                                                                                                                                nodeIdAttr=nodeIdAttr,
+                                                                                                                                                nodeIdVal=nodeIdList[nodeIdIItem])
+                    queryStrList.append(queryStrItem)
+                queryStr=" UNION ".join(queryStrList)
+                nodeItemGInfoDf=wrapNebula2Df(gClient.execute_query(queryStr))
+                nodeItemGInfoDfList.append(nodeItemGInfoDf)
+            nodeItemGInfoDf=pd.concat(nodeItemGInfoDfList)
+            
+            for colItem in nodeItemCInfoDf.columns:
+                idAttrKey=rawSchemaJson["vertex"][vertexI]["id_col"]
+                if colItem !=  idAttrKey:
+                    changedIdList=nodeItemCInfoDf.loc[(nodeItemCInfoDf[colItem].isna())|
+                                                    (nodeItemCInfoDf[colItem]=="null")|
+                                                    (nodeItemCInfoDf[colItem]==""),idAttrKey].values.flatten().tolist()
+                    nodeItemCInfoDf.loc[nodeItemCInfoDf[idAttrKey].str.isin(changedIdList),colItem]=\
+                        nodeItemGInfoDf.loc[nodeItemGInfoDf[idAttrKey].str.isin(changedIdList),colItem]
+            
+            csvDfItem=nodeItemCInfoDf
         elif vertexAttrProcess=="cover":
             pass
         # print(csvDfItem.head())
@@ -233,24 +231,30 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
         elif edgeAttrDataProcess=="plus":
             htList=json.loads(csvDfItem.to_json(orient="records"))
             newHTList=[]
-            for htI in tqdm.tqdm(range(0,len(htList),1024),desc="edge attr control-plus"):
-                htItem=htList[htI]
-                srcIdVal=htItem[srcIdAttr]
-                tgtIdVal=htItem[tgtIdAttr]
-                attrList=[keyItem for keyItem in htItem if keyItem not in [srcIdAttr,tgtIdAttr]]
-                attrGroupStr=",".join(["{edgeType}.{attrName} AS {attrName}".format(edgeType=edgeType,attrName=attrItem) for attrItem in attrList])
-                htItemDf=wrapNebula2Df(gClient.execute_query("LOOKUP ON {headType} WHERE {headType}.{headIdAttrKey}=='{headIdAttrVal}'|\
-                                        GO FROM $-.VertexID OVER {edgeType} WHERE $$.{tailType}.{tailIdAttrKey}=='{tailIdAttrVal}'\
-                                            YIELD {attrGroup}".format(
-                                                headType=srcType,
-                                                headIdAttrKey=srcIdAttr,
-                                                headIdAttrVal=srcIdVal,
-                                                edgeType=edgeType,
-                                                tailType=tgtType,
-                                                tailIdAttrKey=tgtIdAttr,
-                                                tailIdAttrVal=tgtIdVal,
-                                                attrGroup=attrGroupStr
-                                            )))
+            htSearchBatchSize=128
+            for htI in tqdm.tqdm(range(0,len(htList),htSearchBatchSize),desc="edge attr control-plus"):
+                queryStrList=[]
+                for htItem in htList[htI:htI+htSearchBatchSize]:
+                    htItem=htList[htI]
+                    srcIdVal=htItem[srcIdAttr]
+                    tgtIdVal=htItem[tgtIdAttr]
+                    attrList=[keyItem for keyItem in htItem if keyItem not in [srcIdAttr,tgtIdAttr]]
+                    attrGroupStr=",".join(["{edgeType}.{attrName} AS {attrName}".format(edgeType=edgeType,attrName=attrItem) for attrItem in attrList])
+                    queryItemStr="LOOKUP ON {headType} WHERE {headType}.{headIdAttrKey}=='{headIdAttrVal}'|\
+                                            GO FROM $-.VertexID OVER {edgeType} WHERE $$.{tailType}.{tailIdAttrKey}=='{tailIdAttrVal}'\
+                                                YIELD {attrGroup}".format(
+                                                    headType=srcType,
+                                                    headIdAttrKey=srcIdAttr,
+                                                    headIdAttrVal=srcIdVal,
+                                                    edgeType=edgeType,
+                                                    tailType=tgtType,
+                                                    tailIdAttrKey=tgtIdAttr,
+                                                    tailIdAttrVal=tgtIdVal,
+                                                    attrGroup=attrGroupStr
+                                                )
+                    queryStrList.append(queryItemStr)
+                queryStr=" UNION ".format(queryStrList)
+                htItemDf=wrapNebula2Df(gClient.execute_query(queryStr))
                 newHTItemList=json.loads(htItemDf.to_json(orient="records"))
                 for keyItem in attrList:
                     if newHTItemList[0][keyItem] is None or np.nan(newHTItemList[0][keyItem]) or newHTItemList[0][keyItem]=="null":
